@@ -1,7 +1,7 @@
 /*
  *  templatedlg.cpp  -  dialog to create, edit and delete alarm templates
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2004-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -57,7 +57,7 @@ TemplateDlg::TemplateDlg(QWidget* parent)
     hlayout->addLayout(layout);
     mListFilterModel = DataModel::createTemplateListModel(this);
     if (!ShellProcess::authorised())
-        mListFilterModel->setAlarmActionFilter(static_cast<KAEvent::Actions>(KAEvent::ACT_ALL & ~KAEvent::ACT_COMMAND));
+        mListFilterModel->setAlarmActionFilter(static_cast<KAEvent::Action>(KAEvent::Action::All & ~KAEvent::Action::Command));
     mListView = new TemplateListView(this);
     mListView->setModel(mListFilterModel);
     mListView->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
@@ -172,7 +172,7 @@ void TemplateDlg::slotEdit()
 */
 void TemplateDlg::slotDelete()
 {
-    QVector<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> events = mListView->selectedEvents();
     int n = events.count();
     if (KAMessageBox::warningContinueCancel(this, i18ncp("@info", "Do you really want to delete the selected alarm template?",
                                                          "Do you really want to delete the %1 selected alarm templates?", n),
@@ -202,7 +202,7 @@ void TemplateDlg::slotDelete()
 */
 void TemplateDlg::slotSelectionChanged()
 {
-    QVector<KAEvent> events = mListView->selectedEvents();
+    QList<KAEvent> events = mListView->selectedEvents();
     int count = events.count();
     bool readOnly = false;
     for (int i = 0;  i < count;  ++i)
@@ -230,4 +230,6 @@ void TemplateDlg::resizeEvent(QResizeEvent* re)
     QDialog::resizeEvent(re);
 }
 
+#include "moc_templatedlg.cpp"
+
 // vim: et sw=4:
